@@ -1,19 +1,18 @@
-//! # C types FFI opaque pointers.
-//! 
-//! Specific C types like C-like string pointers.
+//! # Specific C types like C-like string pointers.
 
 #![cfg(all(feature = "std", feature = "c-types"))]
 
 use std::os::raw::c_char;
 use std::ffi::CStr;
 
+#[cfg(any(feature = "panic-if-null", debug_assertions))]
 use super::panic_if_null;
 
-/// Reference to a C string.
+/// Convert a reference to a C string into a static reference to Rust `str`.
 /// 
 /// # Safety
 /// 
-/// The pointer must be a valid reference to that value with that type.
+/// The pointer must be a valid reference or behavior is undefined.
 /// 
 /// # Panics
 /// 
@@ -21,6 +20,7 @@ use super::panic_if_null;
 #[must_use]
 #[inline]
 pub unsafe fn ref_str<'a>(string: *const c_char) -> &'a str {
+    #[cfg(any(feature = "panic-if-null", debug_assertions))]
     panic_if_null(string);
     // CAUTION: this is unsafe
     let string = CStr::from_ptr(string);
